summaryrefslogtreecommitdiffstats
path: root/base/base_drop_target.h
diff options
context:
space:
mode:
Diffstat (limited to 'base/base_drop_target.h')
-rw-r--r--base/base_drop_target.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/base/base_drop_target.h b/base/base_drop_target.h
index cf63be28..8be0d36 100644
--- a/base/base_drop_target.h
+++ b/base/base_drop_target.h
@@ -26,12 +26,13 @@ class BaseDropTarget : public IDropTarget {
explicit BaseDropTarget(HWND hwnd);
virtual ~BaseDropTarget();
// When suspend is set to |true|, the drop target does not receive drops from
// drags initiated within the owning HWND.
// TODO(beng): (http://b/1085385) figure out how we will handle legitimate
// drag-drop operations within the same HWND, such as dragging
// selected text to an edit field.
- void set_suspend(bool suspend) { suspend_ = suspend; }
+ bool suspended() const { return suspended_; }
+ void set_suspended(bool suspended) { suspended_ = suspended; }
// IDropTarget implementation:
HRESULT __stdcall DragEnter(IDataObject* data_object,
@@ -120,7 +121,7 @@ class BaseDropTarget : public IDropTarget {
// Whether or not we are currently processing drag notifications for drags
// initiated in this window.
- bool suspend_;
+ bool suspended_;
LONG ref_count_;
@@ -26,12 +26,13 @@ class BaseDropTarget : public IDropTarget {
explicit BaseDropTarget(HWND hwnd);
virtual ~BaseDropTarget();
- // When suspend is set to |true|, the drop target does not receive drops from
- // drags initiated within the owning HWND.
+ // When suspended is set to |true|, the drop target does not receive drops
+ // from drags initiated within the owning HWND.
// TODO(beng): (http://b/1085385) figure out how we will handle legitimate
// drag-drop operations within the same HWND, such as dragging